ApiStatus class

Constructors

ApiStatus({int ok = 200, int created = 201, int updated = 202, int deleted = 203, int canceled = 204})
const

Properties

canceled → int
final
created → int
final
deleted → int
final
hashCode → int
The hash code for this object.
no setterinherited
ok → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updated → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited