EncryptedApi class

Inheritance

Constructors

EncryptedApi({required String api, required String key, required String iv, required String passcode, required Map<String, dynamic> request(String request, String passcode), required dynamic response(Map<String, dynamic> data), ApiRequest type = ApiRequest.post, ApiStatus status = const ApiStatus()})
const

Properties

api → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
iv → String
final
key → String
final
passcode → String
final
request → Map<String, dynamic> Function(String request, String passcode)
final
response → dynamic Function(Map<String, dynamic> data)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ApiStatus
finalinherited
type → ApiRequest
final

Methods

input(dynamic data) → Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(dynamic data) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited